import { GltfAsset } from 'gltf-loader-ts';
import { MeshPrimitive } from 'gltf-loader-ts/lib/gltf';
import { GLTFMesh } from './gltfmesh';
import { GLTFPrimitive } from './gltfprimitive';
import { Context } from '../context';
import { ResourceManager } from '../core';
import { Program } from '../program';
import { Material } from '../scene';
import { SceneNode } from '../scene/scenenode';
import { Texture2D } from '../texture2d';
/**
 * This class can be used to load the glTF file format, which describes scenes and models.
 * It handles all buffer, texture and geometry creation as well as scene generation.
 * Per glTF scene, one SceneNode is generated which represents the hierarchy of the scene.
 * ```
 * const loader = new GLTFLoader(this._context);
 * await loader.loadAsset(GltfRenderer.assetURI);
 * const rootNode = loader.defaultScene;
 * ```
 */
export declare class GLTFLoader {
    protected _context: Context;
    protected _sceneName: string;
    protected _defaultScene: SceneNode | undefined;
    protected _scenes: Array<SceneNode>;
    protected _resourceManager: ResourceManager;
    protected _pbrProgram: Program;
    protected _pbrDefaultMaterial: Material;
    constructor(context: Context);
    protected loadTextures(asset: GltfAsset): Promise<void>;
    protected getTexture(index: number): Texture2D | undefined;
    protected loadMaterials(asset: GltfAsset): Promise<void>;
    protected inferBufferUsage(asset: GltfAsset, bufferViewId: number): GLenum;
    protected loadBuffers(asset: GltfAsset): Promise<void>;
    protected loadMeshes(asset: GltfAsset): Promise<Array<GLTFMesh>>;
    protected loadPrimitive(asset: GltfAsset, primitiveInfo: MeshPrimitive, id: number): Promise<GLTFPrimitive | undefined>;
    protected generateScenes(asset: GltfAsset, meshes: Array<GLTFMesh>): Promise<void>;
    loadAsset(uri: string): Promise<void>;
    uninitialize(): void;
    get pbrProgram(): Program;
    get scenes(): Array<SceneNode>;
    get defaultScene(): SceneNode;
}
